@@ -6,7 +6,7 @@ HERE = (pathlib.Path(__file__).parent)
 # files
 GAME_LEAGUE_ID_FILE = (HERE / 'files/json/game_league_ids.json')
 CLEANED_NAMES_FILE = (HERE / 'files/json/cleaned_names.json')
-OUTPUT_FILE = (HERE / 'files/output/outfile{}.json')
+OUTPUT_FILE = (HERE / 'files/output/outfile.json')
 
 
 def search_json_key(data, json_key):
@@ -14,11 +14,8 @@ def search_json_key(data, json_key):
     return tree.execute('${}'.format(json_key))  # result of search
 
 
-def dump_to_outfile(data, num=None):
-    out_num = ''
-    if num is not None:
-        out_num = num
-    with open(OUTPUT_FILE.format(out_num), 'w') as outfile:
+def dump_to_outfile(data):
+    with open(OUTPUT_FILE, 'w') as outfile:
         json.dump(data, outfile, indent=4)
 
 
